.. _aangifte:

.. raw:: html

    <br>
    <center>

aangifte
========

.. raw:: html

    </center>
    <br>


| Van: Bart Thate [mailto:bthate@gmail.com<mailto:bthate@gmail.com>]
| Verzonden: dinsdag 16 oktober 2012 21:49
| Aan: AP-Alkmaar (Parket Alkmaar); Info Hoge Raad
| Onderwerp: Re: verzoek aan de officier van justitie om tot strafrechtelijke vervolging over te gaan

Hallo Korps Politie,

ik wil hiermee melding maken van een situatie die voor zowel mij als mijn v
riendin levensbedreigend is. Wij hebben al vele malen in de loop van de afg
elopen 4 jaar aangifte proberen te doen van de misstanden hier in de GGZ, h
et is alle keren tegengehouden omdat er geen sprake zou zijn van opzet. Ik 
zal u laten zien wat de situatie is en is zal u ook aangeven dat er wel spr
ake is van opzet.

De situatie:

Mijn vriendin en ik zijn beiden in behandeling geweest bij de GGZ NHN hier 
in Heerhugowaard. Mijn vriendin is er nog steeds in behandeling, ik ben nu 
al weer 2 jaar een zorgwekkende zorgmijdende GGZ patient, omdat de GGZ niet
wenst te leren van de fouten die er gemaakt zijn.
Het betreft hier hiet risico op suicide voor mij en mijn vriendin en de inv
loed op dit risico door het doen en laten van de GGZ.

Mijn vriendin heeft onderandere bordeline, welke stoornis een 2000% (ja 20 
keer) grotere kans op suicide opleverd dan een normaal mens. Ik ben schizof
reen met 700% (7 keer) meer kans om te sterven aan zelfmoord. Het handelen 
van de GGZ met patienten met zulke risico's brengt een enorme verantwoordel
ijkheid met zich mee.

De 1e keer dat mijn vriendin een poging deed was toen een casemanager niet 
op het afgesproken tijdstip belde (nog van voor mijn tijd). De 2e keer was 
omdat de psychiater en casemanager een opname niet nodig vonden. Nu dreigt 
zich een situatie te ontwikkelen waarbij mijn vriendin weer geconfronteerd 
word met een zorgweigering, gisteren was het betreffende behandelende wijkt
eam (5e wijkteam van GGZ NHN) niet bereikbaar voor contact.

Ik heb toen opgetreden als opvanger van de mentale klap, iets wat ik in de 
afgelopen jaren veel heb moeten doen. Heb mijn vriendin opgevangen zogoed a
ls het kon, aan het eind van de avond waren we er weer een beetje overheen.

Ik kan dit niet meer, het is wachten totdat het WEER misgaat. Als de GGZ ni
et adequaat reageert, is het risico te groot en ik kan er niet altijd zijn 
om maar te proberen de gedaande schade te fixen. Om maar niet te spreken ov
er de schade die dit mij toebrengt.

Ik meld dit u, kompleet in de verwachting dat ook deze keer u een smoes zul
t verzinnen waarom u niets doet, zoals u het de afgelopen jaren heeft gedaa
n. U wilt niet eens zien dat er dingen misgaan.
